@@ -1,7 +1,7 @@
 package Bencher::Formatter::ScaleSize;
 
 our $DATE = '2016-04-08'; # DATE
-our $VERSION = '1.004'; # VERSION
+our $VERSION = '1.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -21,7 +21,7 @@ sub munge_result {
 
     return unless @{$envres->[2]};
 
-    my @cols = grep {/^(result_size)\b/} keys %{ $envres->[2][0] };
+    my @cols = grep {/^(result|proc_\w+|proc)_size$/} keys %{ $envres->[2][0] };
     return unless @cols;
 
   COL:
@@ -85,7 +85,7 @@ Bencher::Formatter::ScaleSize - Scale size fields to make it convenient
 
 =head1 VERSION
 
-This document describes version 1.004 of Bencher::Formatter::ScaleSize (from Perl distribution Bencher-Backend), released on 2016-04-08.
+This document describes version 1.005 of Bencher::Formatter::ScaleSize (from Perl distribution Bencher-Backend), released on 2016-04-08.
 
 =for Pod::Coverage .*
 
